Welcome to QmeQ documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 2

   qmeq.rst
   Indexing of states <qmeq.indexing.rst>
   Quantum dot Hamiltonian <qmeq.qdot.rst>
   Tunneling Hamiltonian <qmeq.leadstun.rst>
   Builder class <qmeq.builder.rst>
   Approach class for master equations <qmeq.aprclass.rst>
   Special functions <qmeq.specfunc.rst>
   Various functions <qmeq.various.rst>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

